<template>
  <win-md title="规格型号" @close="close" :width="'800px'">
    <!--列表-->
    <my-table-v2 ref="myTable" :table="table"/>
    <div slot="footer" align="center" class="dialog-footer">
      <my-button name="取消" site="form" @click="close"/>
    </div>
    <specsAdd v-if="specsSetting.show" :setting="specsSetting" @close="specsSetting.show = false" @search="search"/>
  </win-md>
</template>

<script>
import winMd from '@/components/win/win-md'
import myButton from '@/components/myButton/myButton'
import {delSpecs} from "@/api/foudation/material";
import specsAdd from "@/views/foundation/material/specs/specsAdd.vue";
import {mapGetters} from 'vuex'
import MyTableV2 from "@/components/myTable/myTableV2.vue";
import SettingIplatform from "@/utils/settingIplatform";

export default {
  name: 'specs',
  components: {MyTableV2, winMd, myButton, specsAdd},
  props: {
    setting: {
      type: Object,
      default: () => {
      }
    }
  },
  data() {
    return {
      specsSetting: {
        title: '',
        id: '',
        show: false,
      },
      // 表格数据
      table: {
        showIndex: true, // 是否显示序号
        expand: false, // 是否显示详情数据
        dataIndex: 'goodsTemplatesId',
        url: SettingIplatform.apiBaseURL + '/pc/base/goods/models/query/goodsModel', // 请求地址
        // 工具条
        tools: {
          columnsCtrl: {// 列控制按钮
            show: false
          },
          generalExport: {// 通用导出按钮
            show: false
          },
          // 自定义工具条按钮
          custom: [
            {
              name: '新增',
              click: () => {
                this.showAdd(null);
              },
            },
          ]
        },
        // 列信息
        columns: [
          {title: '规格型号', field: 'goodsCode', align: 'left', minWidth: 120},
          {title: '单位', field: 'classification', align: 'center', width: 100},
          {
            field: 'states',
            title: '状态',
            align: 'center',
            width: 100,
            switch: row => {
              const result = {}
              if (row.states == 1) {
                Object.assign(result, {
                  value: true, // 开
                  label: '是', // 开的描述
                  click: () => { // 点击事件
                    this.updState(row)
                  }
                })
              } else {
                Object.assign(result, {
                  value: false, // 关
                  label: '否', // 关的描述
                  click: () => {
                    this.updState(row)
                  }
                })
              }
              return result
            }
          }
        ],
        // 操作信息
        operation: {
          show: true, // 显示操作列
          width: 100, // 列宽
          attr: [
            {
              title: '删除',
              events: (row) => {
                this.del(row);
              },
            },
          ],
        },
        paging: {
          show: true, // 显示分页
          // 分页信息
          page: {
            small: false,
            pageNum: 1,
            pageSize: 10,
            total: 0
          }
        }
      },
    }
  },
  computed: {
    ...mapGetters(['userInfo'])
  },
  created() {
  },
  methods: {
    showAdd(){
      this.specsSetting.mid = this.setting.id;//物品ID
      this.specsSetting.show = true;
    },
    del(row) {
      this.$modal
        .confirm('是否确认删除名称为"' + row.categoryName + '"的机构吗？')
        .then(function () {
          delSpecs({ id: row.id }).then((res) => {});
        })
        .then((res) => {
          this.$message.success('删除成功！');this.$refs.myTable.search();
        })
        .catch(() => {});
    },
    close() {
      this.$emit('close')
    },
    // 查询table列表
    search() {
      this.$refs.myTable.search()
    },

  }
}
</script>
